"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

/**
 * Record Error
 * @alias RecordError
 * @memberof ValidationError
 */

/**
 * Property Errors
 * @alias PropertyErrors
 * @memberof ValidationError
 */

/**
 * Error which is thrown when there are validation errors with records
 * @category Errors
 */
class ValidationError extends Error {
  /**
   * Validation errors for all properties
   */

  /**
   * One root validation error i.e. thrown when user wants to perform
   * an action which violates foreign key constraint
   */

  /**
   * @param {string} message   custom message
   * @param {PropertyErrors} propertyErrors     error messages
   * @param {RecordError} [baseError]           base error
   */
  constructor(message, propertyErrors, baseError) {
    super(message);
    this.propertyErrors = propertyErrors;
    this.baseError = baseError || null;
    this.message = message || 'Resource cannot be stored because of validation errors';
    this.name = 'ValidationError';
  }

}

var _default = ValidationError;
exports.default = _default;