import React from 'react';
import { ThemeProps, DefaultTheme } from 'styled-components';
/**
 * @memberof Illustration
 * @alias IllustrationProps
 */
export declare type IllustrationProps = {
    /**
     * Available illustration variant
     */
    variant: 'Moon' | 'Rocket' | 'Astronaut' | 'DocumentCheck' | 'DocumentSearch' | 'FileSearch' | 'FlagInCog' | 'Folders' | 'Launch' | 'Planet' | 'AdminBroLogo' | 'SoftwareBrothersLogo' | 'GithubLogo';
    /** Optional max width restrictions */
    width?: number;
    /** Optional max height restrictions */
    height?: number;
};
/**
 * Awesome database with all the illustrations provided with AdminBro.
 *
 * The best thing about them is that they follow your {@link Theme} color palette.
 *
 * @component
 * @subcategory Atoms
 *
 * @example <caption>Folders</caption>
 * return (
 *   <Illustration variant="Folders" />
 * )
 * @example <caption>DocumentSearch</caption>
 * return (
 *   <Illustration variant="DocumentSearch" />
 * )
 * @example <caption>Rocket</caption>
 * return (
 *   <Box bg="grey100" p="xxl"><Illustration variant="Rocket" /></Box>
 * )
 */
export declare const Illustration: React.ForwardRefExoticComponent<Pick<React.PropsWithChildren<IllustrationProps & ThemeProps<DefaultTheme>>, "children" | "height" | "width" | "variant"> & {
    theme?: DefaultTheme | undefined;
}>;
export default Illustration;
