import React from 'react';
import { LayoutProps } from 'styled-system';
/**
 * Renders placeholder
 *
 * Usage:
 * ```javascript
 * import { Placeholder, PlaceholderProps } from 'admin-bro'
 * ```
 *
 * @component
 * @subcategory Atoms
 * @example <caption>Image placeholder</caption>
 * return (
 *   <Box>
 *     <Placeholder width={100} height={200} />
 *   </Box>
 * )
 *
 * @example <caption>Text placeholder</caption>
 * return (
 *   <Box>
 *     <Label>Some name</Label>
 *     <Placeholder width={400} height={14} />
 *   </Box>
 * )
 */
export declare const Placeholder: React.FC<PlaceholderProps>;
export declare type PlaceholderProps = LayoutProps & React.HTMLProps<HTMLDivElement> & {
    as?: 'div' | 'span';
};
/**
 * Prop Types of a Placeholder component.
 * Apart from standard html props it extends {@link LayoutProps}
 * @typedef {object} PlaceholderProps
 * @memberof Placeholder
 * @alias PlaceholderProps
 * @property {string} [...] All props default to _div_ html component like `style`,
 *                          `id` etc.
 * @property {string} [...] Props from {@link LayoutProps}
 */
export default Placeholder;
