import { SpaceProps, TypographyProps, LayoutProps } from 'styled-system';
/**
 * Prop Types of a TextArea component.
 * It extends all {@link SpaceProps}, {@link TypographyProps} and {@link LayoutProps}
 * @memberof TextArea
 * @alias TextAreaProps
 * @property {string} [...] All props default to _textarea_ html component like `onChange`,
 *                          `value` etc.
 * @property {string} [...] Props from {@link SpaceProps}, {@link TypographyProps}
 *                          and {@link LayoutProps}
 */
export declare type TextAreaProps = SpaceProps & TypographyProps & LayoutProps;
/**
 * Wrapped `textarea` html element.
 *
 * Usage:
 * ```javascript
 * import { TextArea, TextAreaProps } from 'admin-bro'
 * ```
 *
 * @component
 * @subcategory Atoms
 * @example
 * return (
 *   <Box p="xl">
 *      <Label htmlFor="textarea1">Some example label</Label>
 *      <TextArea id="textarea1" width={1/2} />
 *   </Box>
 * )
 */
export declare const TextArea: import("styled-components").StyledComponent<"textarea", import("styled-components").DefaultTheme, TextAreaProps, never>;
export default TextArea;
