import React from 'react';
import { InputProps } from '../atoms/input';
declare type Variant = InputProps['variant'];
/**
 * Props for DatePicker
 * @memberof DatePicker
 * @alias DatePickerProps
 */
export declare type DatePickerProps = {
    /**
     * selected date
     */
    value?: string | Date;
    /**
     * on change callback taking string as a date
     */
    onChange: (date: string) => void;
    /**
     * variant - the same as variant in {@link InputProps}
     */
    variant?: Variant;
};
/**
 * Component responsible for showing dates. It is a wrapper to
 * [react datepicker]{@link https://reactdatepicker.com/}.
 *
 * @component
 * @subcategory Molecules
 * @see https://reactdatepicker.com/
 *
 * @example
 * return (
 * <Box width={1/2} height="300px">
 *   <DatePicker onChange={(date) => console.log(date)}/>
 * </Box>
 * )
 */
export declare const DatePicker: React.FC<DatePickerProps>;
export default DatePicker;
